@@ -15,11 +15,7 @@ try:
             # recognize speech using Google Speech Recognition
             value = r.recognize_google(audio)
 
-            # we need some special handling here to correctly print unicode characters to standard output
-            if str is bytes:  # this version of Python uses bytes for strings (Python 2)
-                print(u"You said {}".format(value).encode("utf-8"))
-            else:  # this version of Python uses unicode for strings (Python 3+)
-                print("You said {}".format(value))
+            print("You said {}".format(value))
         except sr.UnknownValueError:
             print("Oops! Didn't catch that")
         except sr.RequestError as e:
